@@ -284,89 +284,6 @@ binMed <- function(x,bins,verbose=TRUE){
   return(medbins)
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-#' @title Compute weights from distance matrix
-#'
-#' @description Function for computing a matrix of gaussian or fixed weights from distance matrix
-#'
-#' @param distmat a symmetric matrix of inter-site distances (in km). 
-#' @param h parameter of the Gaussian distance decay function.
-#' @param kernel indicates the type of weighting function, either 'fixed' or 'gaussian'. Default is 'gaussian'. 
-#'
-#' @details This function generates a weight matrix (required for the \code{\link{SPpermTest}}) function. When \code{kernel=="fixed"}, the weight \eqn{w_{ij}} between site \eqn{i} and \eqn{j} is equal to 1 when their interdistance \eqn{d_{ij}} is below \code{h}, and equal to 0 when  \eqn{d_{ij}>h}.When \code{kernel=="gaussian"}, the weight is calculated with formula exp(-d_{ij}^2/h^2).
-#'
-#' @return An object of class spatialweights
-#'
-#' @examples
-#' lon <- c(11.3426,0.1278,0.1218)
-#' lat <- c(44.4949,51.5074,52.2053)
-#' library(sp)
-#' d <- spDists(x=cbind(lon,lat),y=cbind(lon,lat))
-#' spweights(d,h=100)
-#' spweights(d,h=100,kernel="fixed")
-#' @import stats
-#' @export
-
-
-spweights<-function(distmat,h=NULL,kernel="gaussian")
-{
-    w=matrix(NA,nrow=nrow(distmat),ncol=ncol(distmat))
-    kernels <- c("gaussian","fixed")
-    if (!kernel %in% kernels){
-                stop("The kernel you have chosen is not currently an option.")
-           }
-    if (is.null(h))
-    {
-                stop("Distance parameter h undefined")  
-    }
-    for (x in 1:nrow(distmat))
-        {
-            if (kernel=="gaussian")
-                {w[x,]=exp(-distmat[x,]^2/h^2)}
-            if (kernel=="fixed")
-                {w[x,]=as.numeric(distmat[x,]<=h)}
-        }
-    res=list(w=w,h=h,kernel=kernel)
-    class(res) <- append(class(res),"spatialweights")
-    return(res)   
-}
-
 #' @title Computes rates of change from SPDs
 #'
 #' @description Function for computing rates of change between abutting user-defined time-blocks.
